@@ -24,8 +24,8 @@ class Person(models.Model):
 
 class Employee(Person):
     employee_num = models.IntegerField(default=0)
-    profile = models.ForeignKey('Profile', related_name='profiles', null=True)
-    accounts = models.ManyToManyField('Account', related_name='employees', blank=True, null=True)
+    profile = models.ForeignKey('Profile', models.SET_NULL, related_name='profiles', null=True)
+    accounts = models.ManyToManyField('Account', related_name='employees', blank=True)
 
 
 @python_2_unicode_compatible
